@@ -74,6 +74,7 @@ usage: tempor {provider} [-h] [--image image] [--region region] [-s] [-l] [-b] [
 
 options:
   -h, --help            show this help message and exit
+  -c, --count           Number of images to create
   --image image         Specify the OS Image
   --region region       Specify the Region to Host the Image
   --resources resource  Specify the hardware resources for the host image
@@ -81,7 +82,7 @@ options:
   -s, --setup           Create a VPS
   -f, --full            Full Configuration with hardening
   -m, --minimal         Minimal Configuration (just configs)
-  -c, --custom          Specify Ansible playbook for custom configuration (Path to main.yml file)
+  --custom              Specify Ansible playbook for custom configuration (Path to main.yml file)
   --no-config           Do not run any configuration (except custom)
 """
     )
@@ -169,16 +170,21 @@ def terraform_installed() -> str:
     return out_file
 
 
-def rm_hosts(provider: str, workspace: str) -> None:
+def rm_hosts(provider: str, vps_name: str = "") -> None:
     hostnames = list()
     hosts = get_hosts()
 
-    if not hosts or provider not in hosts:
+    if not hosts or (provider not in hosts):
         return
 
     for idx, host in enumerate(hosts[provider]):
         for hostname, values in host.items():
-            if values["workspace"] == workspace:
+            if vps_name:
+                if hostname == vps_name:
+                    hostnames.append(hostname)
+                    del hosts[provider][idx]
+                    remove_config_entry(hostname)
+            else:
                 hostnames.append(hostname)
                 del hosts[provider][idx]
                 remove_config_entry(hostname)
